#
# spec file for package Ne10
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 10
Name:           Ne10
Version:        1.2.1
Release:        3.17
Summary:        A library of common math and DSP functions optimized for ARM NEON
License:        BSD-3-Clause
URL:            https://projectne10.github.com/Ne10/
Source:         https://github.com/projectNe10/Ne10/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
ExclusiveArch:  armv7hl aarch64

%description
The library provides some of the fastest implementations of key
operations available for the ARM v7-A and v8-A architectures,
particularly focusing on math, signal processing, image processing,
and physics functions.

%package -n libNE10-%{sover}
Summary:        A library of common math and DSP functions optimized for ARM NEON

%description -n libNE10-%{sover}
Ne10 is a library of common functions that have been
optimised for ARM-based CPUs equipped with NEON SIMD capabilities.

The library provides some of the fastest implementations of key
operations available for the ARM v7-A and v8-A architectures,
particularly focusing on math, signal processing, image processing,
and physics functions.

This package contains the shared library.

%package -n libNE10_test%{sover}
Summary:        A library of common math and DSP functions optimized for ARM NEON

%description -n libNE10_test%{sover}
The library provides some of the fastest implementations of key
operations available for the ARM v7-A and v8-A architectures,
particularly focusing on math, signal processing, image processing,
and physics functions.

This package contains the shared library with tests.

%package devel
Summary:        Development files for Ne10, a math/DSP library for ARM NEON
Requires:       libNE10-%{sover} = %{version}
Requires:       libNE10_test%{sover} = %{version}

%description devel
The library provides some of the fastest implementations of key
operations available for the ARM v7-A and v8-A architectures,
particularly focusing on math, signal processing, image processing,
and physics functions.

This package contains the development files.

%prep
%setup -q

%build
%cmake \
  %ifarch aarch64
  -DNE10_LINUX_TARGET_ARCH=aarch64 \
  %else
  -DNE10_LINUX_TARGET_ARCH=armv7 \
  %endif
  -DNE10_BUILD_STATIC=OFF \
  -DNE10_BUILD_SHARED=ON \
  -DGNULINUX_PLATFORM=ON
%cmake_build

%install
for i in inc/*.h; do
    install -p -D -m 0644 $i %{buildroot}/%{_includedir}/$(basename $i)
done

for i in build/modules/libNE*so.%{sover}; do
    install -p -D -m 0755 $i %{buildroot}/%{_libdir}/$(basename $i)
    ln -s -r %{buildroot}/%{_libdir}/$(basename $i) %{buildroot}/%{_libdir}/$(basename $i .so.%{sover}).so
done

%post -n libNE10-%{sover} -p /sbin/ldconfig
%post -n libNE10_test%{sover} -p /sbin/ldconfig
%postun -n libNE10-%{sover} -p /sbin/ldconfig
%postun -n libNE10_test%{sover} -p /sbin/ldconfig

%files -n libNE10-%{sover}
%license LICENSE
%{_libdir}/libNE10.so.%{sover}*

%files -n libNE10_test%{sover}
%license LICENSE
%{_libdir}/libNE10_test.so.%{sover}*

%files devel
%{_includedir}/*.h
%{_libdir}/libNE10.so
%{_libdir}/libNE10_test.so

%changelog
* Tue Nov  5 2019 Martin Pluskal <mpluskal@suse.com>
- Use modern macros for building
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Nov 22 2016 schwab@suse.de
- Fix dependencies
* Sat Nov 19 2016 jengelh@inai.de
- Update descriptions with some more useful info
* Fri Aug 26 2016 mpluskal@suse.com
- Update to version 1.2.1:
  * [dsp] Call appropriate NEON butterfly functions in
    NE10_fft_int32.neon.c
  * [dsp] Prevent overflow by moving scaling in front of butterfly
  * [dsp] Link stdc++ for static build
  * [all] Switch to intrinsic on iOS
  * [dsp] Fix NE10_INLINE_ASM_OPT for RFFT
  * [math] Limit the range of input to avoid the failed tests in
    math module
  * [dsp] Fix test_suite_fft_int32.c fails under armv7
  * For 4-point and 8-point FFTs, we fall back to VFP because they
    are too short for NEON optimizations
  * [all] Main fuction in tests return 0 if all tests pass
  * [all] Enable neon code on ARM32 in physics, dsp and image
    modules
  * [dsp] Improve data layout in RFFT float32
* Wed May  1 2013 dmueller@suse.com
- fix package version
- split -devel package
- install headers
- various build fixes
* Wed Apr 17 2013 awafaa@opensuse.org
- Split binary to reflect lib
* Tue Apr 16 2013 awafaa@opensuse.org
- Update license to BSD-3-Clause
* Tue Apr 16 2013 awafaa@opensuse.org
- Clean spec file and add fdupes requirement
* Wed Mar 27 2013 awafaa@opensuse.org
- Initial import for openSUSE version 20130327
